@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package MetaCPAN::Client;
 # ABSTRACT: A comprehensive, DWIM-featured client to the MetaCPAN API
-$MetaCPAN::Client::VERSION = '2.025000';
+$MetaCPAN::Client::VERSION = '2.029000';
 use Moo;
 use Carp;
 use Ref::Util qw< is_arrayref is_hashref is_ref >;
@@ -200,10 +200,36 @@ sub all {
 }
 
 sub download_url {
-    my $self   = shift;
-    my $module = shift;
+    my $self             = shift;
+    my $module           = shift;
+    my $version_or_range = shift;
+    my $dev              = shift;
 
-    return $self->_get( 'download_url', $module );
+    my $uri = $module;
+    my @extra;
+    if ( defined $version_or_range ) {
+
+        my @valid_ranges =  qw{ == != <= >= < > ! };
+        my $is_using_range;
+        foreach my $range ( @valid_ranges ) {
+            if ( index( $version_or_range, $range ) >= 0 ) {
+                $is_using_range = 1;
+                last;
+            }
+        }
+        # by default use the '==' operator when no range set
+        $version_or_range = '==' . $version_or_range unless $is_using_range;
+
+        # version=>0.21,<0.27,!=0.26&dev=1
+        push @extra, 'version=' .uri_escape_utf8($version_or_range);
+    }
+    if ( defined $dev ) {
+        push @extra, 'dev=' . uri_escape_utf8($dev);
+    }
+
+    $uri .= '?'.join('&', @extra) if scalar @extra;
+
+    return $self->_get( 'download_url', $uri );
 }
 
 sub autocomplete {
@@ -422,7 +448,7 @@ MetaCPAN::Client - A comprehensive, DWIM-featured client to the MetaCPAN API
 
 =head1 VERSION
 
-version 2.025000
+version 2.029000
 
 =head1 SYNOPSIS
 
@@ -625,7 +651,23 @@ formats (html, plain, x_pod & x_markdown).
 
 Retrieve information from the 'download_url' endpoint
 
-    my $download_url = $mcpan->download_url('Moose')
+    my $download_url = $mcpan->download_url($distro, [$version_or_range, $dev]);
+
+    # request the last available version
+    my $download_url = $mcpan->download_url('Moose');
+
+    # request an older version
+    my $download_url = $mcpan->download_url('Moose', '1.01');
+
+    # using a range
+    my $download_url = $mcpan->download_url('Moose', '<=1.01');
+    my $download_url = $mcpan->download_url('Moose', '>1.01,<=2.00');
+
+Range operators are '== != <= >= < > !'.
+You can use a comma ',' to add multiple rules.
+
+    # requesting dev release
+    my $download_url = $mcpan->download_url('Moose', '>1.01', 1);
 
 Returns a L<MetaCPAN::Client::DownloadURL> object
 
@@ -769,6 +811,15 @@ key:
         ]
     } );
 
+Or, to get either the given version of a release, or the latest:
+
+    my $releases = $mcpan->release( {
+        all => [
+          { distribution => 'GraphViz2' },
+          ($version ? { version => $version } : { status => 'latest' }),
+        ],
+    } );
+
 If you want to do something even more complicated,
 You can also nest your queries, e.g.:
 
